import { API, Client } from "..";
/**
 * System Message
 */
export declare abstract class SystemMessage {
    protected client?: Client;
    readonly type: API.SystemMessage["type"];
    /**
     * Construct System Message
     * @param client Client
     * @param type Type
     */
    constructor(client: Client, type: API.SystemMessage["type"]);
    /**
     * Create an System Message from an API System Message
     * @param client Client
     * @param embed Data
     * @returns System Message
     */
    static from(client: Client, message: API.SystemMessage): SystemMessage;
}
/**
 * Text System Message
 */
export declare class TextSystemMessage extends SystemMessage {
    readonly content: string;
    /**
     * Construct System Message
     * @param client Client
     * @param systemMessage System Message
     */
    constructor(client: Client, systemMessage: API.SystemMessage & {
        type: "text";
    });
}
/**
 * User System Message
 */
export declare class UserSystemMessage extends SystemMessage {
    readonly userId: string;
    /**
     * Construct System Message
     * @param client Client
     * @param systemMessage System Message
     */
    constructor(client: Client, systemMessage: API.SystemMessage & {
        type: "user_added" | "user_remove" | "user_joined" | "user_left" | "user_kicked" | "user_banned";
    });
    /**
     * User this message concerns
     */
    get user(): import("./User").User | undefined;
}
/**
 * User Moderated System Message
 */
export declare class UserModeratedSystemMessage extends UserSystemMessage {
    readonly byId: string;
    /**
     * Construct System Message
     * @param client Client
     * @param systemMessage System Message
     */
    constructor(client: Client, systemMessage: API.SystemMessage & {
        type: "user_added" | "user_remove";
    });
    /**
     * User this action was performed by
     */
    get by(): import("./User").User | undefined;
}
/**
 * Channel Edit System Message
 */
export declare class ChannelEditSystemMessage extends SystemMessage {
    readonly byId: string;
    /**
     * Construct System Message
     * @param client Client
     * @param systemMessage System Message
     */
    constructor(client: Client, systemMessage: API.SystemMessage & {
        type: "channel_renamed" | "channel_description_changed" | "channel_icon_changed";
    });
    /**
     * User this action was performed by
     */
    get by(): import("./User").User | undefined;
}
/**
 * Channel Renamed System Message
 */
export declare class ChannelRenamedSystemMessage extends ChannelEditSystemMessage {
    readonly name: string;
    /**
     * Construct System Message
     * @param client Client
     * @param systemMessage System Message
     */
    constructor(client: Client, systemMessage: API.SystemMessage & {
        type: "channel_renamed";
    });
}
/**
 * Channel Ownership Change System Message
 */
export declare class ChannelOwnershipChangeSystemMessage extends SystemMessage {
    readonly fromId: string;
    readonly toId: string;
    /**
     * Construct System Message
     * @param client Client
     * @param systemMessage System Message
     */
    constructor(client: Client, systemMessage: API.SystemMessage & {
        type: "channel_ownership_changed";
    });
    /**
     * User giving away channel ownership
     */
    get from(): import("./User").User | undefined;
    /**
     * User receiving channel ownership
     */
    get to(): import("./User").User | undefined;
}
//# sourceMappingURL=SystemMessage.d.ts.map